---
name: "\U0001F680 Feature request"
about: "Suggest an idea for this project \U0001F4A1"
title: ''
labels: enhancement
assignees: ''

---

Make sure you've completed the following steps before submitting your issue -- thank you!

1. Search the [issue tracker][] to check if your feature has already been
   mentioned / rejected / planned in other issues.
2. Consider asking in the our chat room at the [Unitary Fund Discord][] to see
   if this is interesting / useful to a larger audience.

[issue tracker]: https://github.com/boschmitt/tweedledum/issues
[Unitary Fond Discord]: http://discord.unitary.fund/

*After reading, remove this checklist. Thanks for helping us improve 
`tweedledum`!*

### Is your feature request related to a problem? Please describe.
<!-- A clear and concise description of what the problem is. -->

### Describe the solution you'd like
<!-- A clear and concise description of what you want to happen. -->

### Describe alternatives you've considered
<!-- A clear and concise description of any alternative solutions or features you've considered. -->

### Additional context
<!-- Add any other context about the feature request here. -->
